from flask import flash, redirect, render_template, url_for
from flask_login import current_user, login_required
from . import admin
from .forms import EditGeneralSettingsAdminForm
from .. import db
from ..decorators import admin_required
from ..models import Role, User
from ..settings import tasks as settings_tasks


@admin.route('/users')
@login_required
@admin_required
def users():
    users = User.query.all()
    users = [dict(username=u.username,
                  email=u.email,
                  role_id=u.role_id,
                  confirmed=u.confirmed,
                  id=u.id)
             for u in users]
    return render_template('admin/users.html.j2', title='Users', users=users)


@admin.route('/users/<int:user_id>')
@login_required
@admin_required
def user(user_id):
    user = User.query.get_or_404(user_id)
    return render_template('admin/user.html.j2', title='User', user=user)


@admin.route('/users/<int:user_id>/delete')
@login_required
@admin_required
def delete_user(user_id):
    settings_tasks.delete_user(user_id)
    flash('User has been deleted!')
    return redirect(url_for('.users'))


@admin.route('/users/<int:user_id>/edit_general_settings',
             methods=['GET', 'POST'])
@login_required
@admin_required
def edit_general_settings(user_id):
    user = User.query.get_or_404(user_id)
    form = EditGeneralSettingsAdminForm(user=user)
    if form.validate_on_submit():
        user.setting_dark_mode = form.dark_mode.data
        user.email = form.email.data
        user.username = form.username.data
        user.confirmed = form.confirmed.data
        user.role = Role.query.get(form.role.data)
        db.session.add(user)
        db.session.commit()
        flash('The profile has been updated.')
        return redirect(url_for('admin.edit_general_settings', user_id=user.id))
    form.confirmed.data = user.confirmed
    form.dark_mode.data = user.setting_dark_mode
    form.email.data = user.email
    form.role.data = user.role_id
    form.username.data = user.username
    return render_template('admin/edit_general_settings.html.j2',
                           form=form,
                           title='General settings',
                           user=user)
